@@ -1,5 +1,5 @@
 from AppiumLibrary import AppiumLibrary
-from airtest.core.settings import Settings as ST
+from airobots.core.settings import ST
 from airtest import aircv
 from airobots.core.api import G
 from appium import webdriver
@@ -12,14 +12,13 @@ import base64
 import time
 
 
-if not hasattr(ST, 'REMOTE_URL'): ST.REMOTE_URL = None
-
 class AirAppium(AppiumLibrary):
     def __init__(self, timeout=5):
         super(AirAppium, self).__init__(timeout=timeout)
 
     @allure.step
-    def open_application(self, remote_url=ST.REMOTE_URL, alias=None, **kwargs):
+    def open_application(self, remote_url=ST.REMOTE_URL, alias=None, platformName=ST.PLATFORM_NAME, **kwargs):
+        kwargs['platformName'] = platformName
         desired_caps = kwargs
         application = webdriver.Remote(str(remote_url), desired_caps)
 
@@ -384,8 +383,8 @@ class AirAppium(AppiumLibrary):
         width, height = self.get_current_resolution()
         if x == y == cx == cy == 0: x, y = width/2, height/2
         elif cx and cy: x, y = cx, cy
-        p1x, p1y = width*0.2, height*0.2
-        p2x, p2y = width*0.8, height*0.8
+        p1x, p1y = width*0.2, y
+        p2x, p2y = width*0.8, y
         p1 = TouchAction(self.driver)
         p2 = TouchAction(self.driver)
         if in_or_out == 'out':
@@ -404,8 +403,8 @@ class AirAppium(AppiumLibrary):
         x, y = element_location.get('x'), element_location.get('y')
         width, height = self.get_current_resolution()
         if x == y == 0: x, y = width/2, height/2
-        p1x, p1y = width*0.2, height*0.2
-        p2x, p2y = width*0.8, height*0.8
+        p1x, p1y = width*0.2, y
+        p2x, p2y = width*0.8, y
         p1 = TouchAction(self.driver)
         p2 = TouchAction(self.driver)
         p1.press(x=x, y=y).wait(500).move_to(x=p1x, y=p1y).wait(50).release()
